@@ -1,6 +1,6 @@
 package SPVM::Go;
 
-our $VERSION = "0.002";
+our $VERSION = "0.003";
 
 1;
 
@@ -64,6 +64,10 @@ Suspends the current goroutine.
 
 The control is transferred to the scheduler.
 
+Exceptions:
+
+This method must be called from the main thread. Otherwise an exception is thrown.
+
 =head2 gosched_io_read
 
 C<static method gosched_io_read : void ($fd : int, $timeout_ref : double[] = undef);>
@@ -74,6 +78,10 @@ The control is transferred to the scheduler.
 
 The value of $timeout_ref is updated by the rest timeout. If it is less than 0, timeout has occured.
 
+Exceptions:
+
+This method must be called from the main thread. Otherwise an exception is thrown.
+
 =head2 gosched_io_write
 
 C<static method gosched_io_write : void ($fd : int, $timeout_ref : double[] = undef);>
@@ -84,12 +92,20 @@ The control is transferred to the scheduler.
 
 The value of $timeout_ref is updated by the rest timeout. If it is less than 0, timeout has occured.
 
+Exceptions:
+
+This method must be called from the main thread. Otherwise an exception is thrown.
+
 =head2 sleep
 
 C<static method sleep : void ($seconds : double = 0);>
 
 Sleeps the seconds $seconds.
 
+Exceptions:
+
+This method must be called from the main thread. Otherwise an exception is thrown.
+
 =head1 Repository
 
 L<SPVM::Go - Github|https://github.com/yuki-kimoto/SPVM-Go>
